import os
from .gatfilter import filter_augment

name = "gatfilter"

__version__ = '0.1.0'
__licence__ = 'MIT'
__author__ = 'Sherry J.H. Feng'
__url__ = 'https://github.com/SherryFeng123/gatfilter/'

PACKAGE_DIR = os.path.dirname(os.path.abspath(__file__))